ODTbrain documentation
======================
Install [numpydoc](https://pypi.python.org/pypi/numpydoc):

    pip install numpydoc

To compile the documentation, run

    python setup.py build_sphinx

